BaselinePaths class

Constructors

BaselinePaths(List<String>? patterns)

Properties

hashCode int
The hash code for this object.
no setterinherited
hasPatterns bool
Whether any patterns are configured.
no setter
patternCount int
Number of patterns configured.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

matches(String? filePath) bool
Check if a file path matches any of the baseline patterns.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited