ContentRegions class

Pre-indexed content regions for targeted scanning.

Constructors

ContentRegions({required String importRegion, required List<String> classDeclarations, required String topLevelCode, required bool hasMain})
const

Properties

classDeclarations List<String>
Class declaration headers (just the "class X extends Y" parts).
final
hashCode int
The hash code for this object.
no setterinherited
hasMain bool
Whether file has a main() function.
final
importRegion String
Lines containing import/export statements.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topLevelCode String
Top-level code outside of classes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited