FileType enum

Classification of a Dart file for rule filtering.

Inheritance
Available extensions

Values

widget → const FileType

A widget file (contains StatelessWidget, StatefulWidget, etc.)

test → const FileType

A test file (*_test.dart, in test/ directory)

bloc → const FileType

A Bloc/Cubit file (contains Bloc, Cubit classes)

provider → const FileType

A Provider/Riverpod file (contains providers)

model → const FileType

A model/entity file (data classes, entities)

service → const FileType

A service/repository file

general → const FileType

Unknown or general Dart file

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FileType>
A constant List of the values in this enum, in order of their declaration.