OwaspMapping class

OWASP mapping for a lint rule.

Contains the OWASP categories from both Mobile Top 10 and Web Top 10 that a rule helps prevent.

Constructors

OwaspMapping({Set<OwaspMobile> mobile = const <OwaspMobile>{}, Set<OwaspWeb> web = const <OwaspWeb>{}})
Creates an OWASP mapping with the specified categories.
const

Properties

allIds List<String>
Returns all category IDs as a combined list.
no setter
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Returns true if this mapping has no categories.
no setter
isNotEmpty bool
Returns true if this mapping has any categories.
no setter
mobile Set<OwaspMobile>
OWASP Mobile Top 10 categories this rule addresses.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
web Set<OwaspWeb>
OWASP Web Top 10 categories this rule addresses.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited