impact property
Each occurrence is a serious issue that should be fixed immediately.
Implementation
@override
LintImpact get impact => LintImpact.error;
Each occurrence is a serious issue that should be fixed immediately.
@override
LintImpact get impact => LintImpact.error;