RuleStatus enum

Lifecycle status of a rule.

  • ready: Stable; recommended for production use.
  • beta: Under evaluation; may have more false positives or behavior changes.
  • deprecated: No longer recommended; will be removed in a future version.
Inheritance
Available extensions

Values

ready → const RuleStatus
beta → const RuleStatus
deprecated → const RuleStatus

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RuleStatus>
A constant List of the values in this enum, in order of their declaration.