RuleTimingRecord class

A record of timing data for a single rule.

Constructors

RuleTimingRecord({required String ruleName, required Duration totalTime, required int callCount, required Duration averageTime})
const

Properties

averageTime Duration
final
callCount int
final
hashCode int
The hash code for this object.
no setterinherited
ruleName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalTime Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object>
Stable JSON shape for CI and post-processing scripts.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited