ScanDiagnostic class
A single lint diagnostic found during scanning.
Constructors
- ScanDiagnostic({required String ruleName, required String filePath, required int line, required int column, required int offset, required int length, required int endLine, required int endColumn, required String severity, required String? problemMessage, String? correctionMessage, String? impact})
-
const
Properties
- column → int
-
1-based start column.
final
- correctionMessage → String?
-
final
- endColumn → int
-
1-based end column (exclusive — one past the last highlighted character).
final
- endLine → int
-
1-based end line (inclusive).
final
- filePath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- impact → String?
-
Rule-declared impact level (error, warning, info), independent of the
analyzer severity. Null for non-saropa diagnostics that have no impact.
final
- length → int
-
final
- line → int
-
1-based start line.
final
- offset → int
-
final
- problemMessage → String?
-
final
- ruleName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited