laneStats property
When true, prints how many rules are in the light lane vs full-only,
making the lane gate's effect observable. Activated by --lane-stats.
Implementation
final bool laneStats;
When true, prints how many rules are in the light lane vs full-only,
making the lane gate's effect observable. Activated by --lane-stats.
final bool laneStats;