targetLine property

int targetLine
final

1-based line number the ignore was intended to suppress (same line for inline ignores, next line for standalone ignores).

Implementation

final int targetLine;