StaleIgnoreFixResult class

Result of fixing stale ignores in a single file: tracks the count of removed ignore directives and the rewritten file content.

Constructors

StaleIgnoreFixResult({required String filePath, required int removedCount})
const

Properties

filePath String
Path to the file that was modified.
final
hashCode int
The hash code for this object.
no setterinherited
removedCount int
Number of stale ignore directives removed from this file.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited