RuleTimingRecord class
A record of timing data for a single rule.
Constructors
- RuleTimingRecord({required String ruleName, required Duration totalTime, required int callCount, required Duration averageTime})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object> - Stable JSON shape for CI and post-processing scripts.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited