ViolationBatch class
Batches violations for more efficient reporting.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- pendingCount → int
-
Get count of pending violations.
no setter
Static Methods
-
add(
{required String filePath, required String ruleName, required int offset, required int length, required String message, required String? correction}) → void - Queue a violation for batched reporting.
-
clear(
) → void - Clear all pending without reporting.
-
flush(
) → List< _BatchedViolation> - Flush all pending violations.