ScanDiagnostic class

A single lint diagnostic found during scanning.

Constructors

ScanDiagnostic({required String ruleName, required String filePath, required int line, required int column, required int offset, required int length, required String severity, required String? problemMessage, String? correctionMessage})
const

Properties

column int
final
correctionMessage String?
final
filePath String
final
hashCode int
The hash code for this object.
no setterinherited
length int
final
line int
final
offset int
final
problemMessage String?
final
ruleName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited