tier property
Optional tier name (e.g. essential, recommended, pedantic). When set, the rule set is taken from this tier and the project's diagnostics: section is not used.
Implementation
final String? tier;
Optional tier name (e.g. essential, recommended, pedantic). When set, the rule set is taken from this tier and the project's diagnostics: section is not used.
final String? tier;